/*
 * Copyright 2019-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fairphone.fp2.settings.app

import android.app.Notification
import android.app.NotificationChannel
import android.app.NotificationManager
import android.app.PendingIntent
import android.content.Context
import android.content.Intent
import androidx.annotation.DrawableRes
import androidx.core.app.NotificationCompat
import com.fairphone.fp2.settings.R

object NotificationDelegate {

    fun buildNotification(
        context: Context,
        channelId: String,
        @DrawableRes iconResId: Int,
        title: String?,
        message: String?,
        pendingIntent: PendingIntent? = null,
        isPersistent: Boolean = false
    ): Notification {
        return NotificationCompat.Builder(context, channelId)
            .setColor(context.getColor(R.color.colorPrimary))
            .setSmallIcon(iconResId)
            .setContentTitle(title)
            .setContentText(message)
            .setStyle(NotificationCompat.BigTextStyle().bigText(message))
            .setContentIntent(pendingIntent)
            .setOngoing(isPersistent)
            .setAutoCancel(true)
            .build()
    }

    fun buildPendingIntent(
        context: Context,
        requestCode: Int,
        intent: Intent,
        flags: Int = 0
    ): PendingIntent = PendingIntent.getActivity(context, requestCode, intent, flags)

    fun displayNotification(context: Context, notificationId: Int, notification: Notification) {
        getNotificationManager(context)
            .notify(notificationId, notification)
    }

    fun createNotificationChannel(
        context: Context,
        channelId: String,
        name: String,
        description: String,
        importance: Int = NotificationManager.IMPORTANCE_DEFAULT
    ) {
        val channel = NotificationChannel(channelId, name, importance).apply {
            this.description = description
        }
        getNotificationManager(context).createNotificationChannel(channel)
    }

    private fun getNotificationManager(context: Context): NotificationManager =
        context.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
}