/*
 * Copyright 2019-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fairphone.fp2.settings.receivers

import android.app.Notification
import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.util.Log
import com.fairphone.fp2.settings.R
import com.fairphone.fp2.settings.app.NotificationDelegate
import com.fairphone.fp2.settings.app.Settings
import com.fairphone.fp2.settings.ui.FairphoneSettingsActivity

class BootBroadcastReceiver : BroadcastReceiver() {

    override fun onReceive(context: Context, intent: Intent) {
        if (intent.action != Intent.ACTION_BOOT_COMPLETED) return

        Log.d(TAG, "${Intent.ACTION_BOOT_COMPLETED} received")
        displayNotificationIfNeeded(context)
    }

    private fun displayNotificationIfNeeded(context: Context) {
        if (shouldDisplayNotification(context)) {
            displayPersistentNotification(context)
        }
    }

    private fun shouldDisplayNotification(context: Context): Boolean {
        return !Settings.hasShownNotification(context)
    }

    private fun displayPersistentNotification(context: Context) {
        val notification = buildOpenGLESNotification(context)
        NotificationDelegate.displayNotification(
            context,
            OPENGLES_NOTIFCATION_ID,
            notification
        )
    }

    private fun buildOpenGLESNotification(context: Context): Notification {
        val pendingIntent = NotificationDelegate.buildPendingIntent(
            context,
            OPENGLES_NOTIFICATION_REQUEST_CODE,
            FairphoneSettingsActivity.getNewIntent(context)
        )
        return NotificationDelegate.buildNotification(
            context = context,
            channelId = context.getString(R.string.notification_channel_id),
            iconResId = R.drawable.ic_3d_rotation_black_24dp,
            title = context.getString(R.string.notification_title),
            message = context.getString(R.string.notification_message),
            pendingIntent = pendingIntent,
            isPersistent = true
        )
    }

    companion object {
        const val TAG = "BootBroadcastReceiver"
        const val OPENGLES_NOTIFCATION_ID = 1331
        const val OPENGLES_NOTIFICATION_REQUEST_CODE = 1331
    }
}