/*
 * Copyright 2019-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.fp2.settings.ui

import android.content.Context
import android.os.PowerManager
import androidx.lifecycle.ViewModel
import com.fairphone.fp2.settings.app.Settings

class FairphoneSettingViewModel : ViewModel() {

    fun isOpenGLES30Enabled(): Boolean = Settings.isOpenGLES30Enabled()
    fun isGyroscopeEnabled(): Boolean = Settings.isGyroscopeEnabled()

    fun applySettingsAndRestart(enableGLES30: Boolean, enableGyroscope: Boolean, context: Context) {
        enableOpenGLES30(enableGLES30)
        enableGyroscope(enableGyroscope)
        restartPhone(context)
    }

    private fun enableOpenGLES30(enable: Boolean): Boolean = Settings.enableOpenGLES30(enable)

    private fun enableGyroscope(enable: Boolean): Boolean = Settings.enableGyroscope(enable)

    private fun restartPhone(context: Context) {
        val pm = context.getSystemService(Context.POWER_SERVICE) as PowerManager
        pm.reboot(null)
    }
}
