/*
 * Copyright 2019-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.fp2.settings.ui

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.lifecycle.ViewModelProvider
import com.fairphone.fp2.settings.app.Settings
import com.fairphone.fp2.settings.databinding.MainFragmentBinding

class FairphoneSettingsFragment : Fragment() {

    private var _binding: MainFragmentBinding? = null
    // This property is only valid between onCreateView and
    // onDestroyView.
    private val binding get() = _binding!!

    private val viewModel: FairphoneSettingViewModel by lazy {
        ViewModelProvider(this).get(FairphoneSettingViewModel::class.java)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        Settings.setHasShownNotification(requireContext())
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        _binding = MainFragmentBinding.inflate(inflater, container, false)
        val view = binding.root
        return view
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }

    override fun onResume() {
        super.onResume()
        initButtons()
    }

    private fun initButtons() {
        binding.switchOpenGlSetting.isChecked = viewModel.isOpenGLES30Enabled()
        binding.switchGyroscopeSetting.isChecked = viewModel.isGyroscopeEnabled()
        binding.buttonApplyReboot.setOnClickListener {
            onRestartPressed()
        }
    }

    private fun onRestartPressed() {
        val enableGLES30 = binding.switchOpenGlSetting.isChecked
        val enableGyroscope = binding.switchGyroscopeSetting.isChecked
        viewModel.applySettingsAndRestart(enableGLES30, enableGyroscope, requireContext())
    }

    companion object {
        fun newInstance() = FairphoneSettingsFragment()
    }
}
